pub struct Backend<Block>where
Block: Block,{ /* private fields */ }Expand description
Disk backend.
Disk backend keeps data in a key-value store. In archive mode, trie nodes are kept from all blocks. Otherwise, trie nodes are kept only from some recent blocks.
Implementations
Sourceimpl<Block> Backend<Block>where
Block: Block,
impl<Block> Backend<Block>where
Block: Block,
Sourcepub fn new(
db_config: DatabaseSettings,
canonicalization_delay: u64,
) -> Result<Backend<Block>, Error>
pub fn new( db_config: DatabaseSettings, canonicalization_delay: u64, ) -> Result<Backend<Block>, Error>
Create a new instance of database backend.
The pruning window is how old a block must be before the state is pruned.
Sourcepub fn reset_trie_cache(&self)
pub fn reset_trie_cache(&self)
Reset the shared trie cache.