pub struct ExtendedHostFunctions<Base, Overlay> { /* private fields */ }Expand description
A wrapper which merges two sets of host functions, and allows the second set to override the host functions from the first set.