pub struct Pointer<T> { /* private fields */ }Expand description
Type to represent a pointer in wasm at the host.
Implementations
Sourceimpl<T> Pointer<T>where
T: PointerType,
impl<T> Pointer<T>where
T: PointerType,
Sourcepub fn offset(self, offset: u32) -> Option<Pointer<T>>
pub fn offset(self, offset: u32) -> Option<Pointer<T>>
Calculate the offset from this pointer.
offset is in units of T. So, 3 means 3 * mem::size_of::<T>() as offset to the
pointer.
Returns an Option to respect that the pointer could probably overflow.
Sourcepub fn cast<R>(self) -> Pointer<R>where
R: PointerType,
pub fn cast<R>(self) -> Pointer<R>where
R: PointerType,
Cast this pointer of type T to a pointer of type R.