pub enum Mutability {
Const,
Var,
}Expand description
Indicator of whether a global value, struct’s field, or array type’s elements are mutable or not.
Variants
Const
The global value, struct field, or array elements are constant and the value does not change.
Var
The value of the global, struct field, or array elements can change over time.
Implementations