pub struct Middleware<S> { /* private fields */ }Expand description
JSON-RPC middleware that handles metrics and rate-limiting.
These are part of the same middleware because the metrics needs to know whether a call was rate-limited or not because it will impact the roundtrip for a call.