Umbrella crate for Soil client and service crates.
This crate provides short module-style re-exports for the main soil-*
crates used to compose a node.
The consensus algorithm crates are feature-gated. Enable them individually
via aura, babe, beefy, grandpa, manual-seal, and pow, or enable
all of them with full.
Examples
use soil::{client, consensus, service};use soil::grandpa;Modules
- chain_
spec - This crate includes structs and utilities for defining configuration files (known as chain specification) for both runtime and node.
- cli
- Substrate CLI library.
- client
- Substrate client libraries.
- consensus
- Collection of common engine-support consensus implementations.
- network
- Substrate-specific P2P networking.
- offchain
- Substrate offchain workers.
- rpc
- Substrate RPC primitives and utilities.
- service
- Substrate service. Starts a thread that spins up the network, client, and extrinsic pool. Manages communication between them.
- sync_
state_ rpc - A RPC handler to create sync states for light clients.
- telemetry
- Substrate’s client telemetry is a part of substrate that allows ingesting telemetry data with for example Polkadot telemetry.
- txpool
- Substrate transaction pool implementation.