Client-side block import and import queue primitives.
Modules
- block_
import - Block import helpers.
- queue
- Import Queue primitive: something which can verify and import blocks.
Structs
- Basic
Queue - Interface to a basic block import queue that is importing blocks sequentially in a separate task, with plugable verification.
- Block
Check Params - Data required to check validity of a Block.
- Block
Import Params - Data required to import a Block.
- Imported
Aux - Auxiliary data associated with an imported block result.
- Imported
State - Imported state data. A vector of key-value pairs that should form a trie.
- Incoming
Block - Block data used by the queue.
- Runtime
Origin - Opaque identifier of the source that supplied network-imported data.
Enums
- Block
Import Error - Block import error.
- Block
Import Status - Block import successful result.
- Fork
Choice Strategy - Fork choice strategy.
- Import
Result - Block import result.
- Justification
Import Result - The result of importing a justification.
- State
Action - Defines how a new state is computed for a given imported block.
- Storage
Changes - Precomputed storage.
Traits
- Block
Import - Block import trait.
- Import
Queue - Import
Queue Service - Blocks import queue API.
- Justification
Import - Justification import trait
- Justification
Sync Link - Control the synchronization process of block justifications.
- Link
- Hooks that the verification queue can use to influence the synchronization algorithm.
- Verifier
- Verify a justification of a block
Functions
- import_
single_ block - Single block import function.
Type Aliases
- BoxBlock
Import - Shared block import struct used by the queue.
- BoxJustification
Import - Shared justification import struct used by the queue.
- Default
Import Queue - A commonly-used Import Queue type.